.. _spkg_websocket_client:

websocket_client: WebSocket client for Python with low level API options
========================================================================

Description
-----------

WebSocket client for Python with low level API options

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/websocket-client/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.9.0

version_requirements.txt::

    websocket-client

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install websocket-client

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i websocket_client


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
